summaryrefslogtreecommitdiffstats
path: root/konq-plugins/rellinks
diff options
context:
space:
mode:
Diffstat (limited to 'konq-plugins/rellinks')
-rw-r--r--konq-plugins/rellinks/ChangeLog2
-rw-r--r--konq-plugins/rellinks/Makefile.am2
-rw-r--r--konq-plugins/rellinks/plugin_rellinks.cpp8
-rw-r--r--konq-plugins/rellinks/plugin_rellinks.h12
4 files changed, 12 insertions, 12 deletions
diff --git a/konq-plugins/rellinks/ChangeLog b/konq-plugins/rellinks/ChangeLog
index bc62fdf..86b4b48 100644
--- a/konq-plugins/rellinks/ChangeLog
+++ b/konq-plugins/rellinks/ChangeLog
@@ -26,6 +26,6 @@ Sun Mar 21 16:23 CET 2004 - Franck Quélain <shift@free.fr>
o Distinction between "rel" and "rev" relations
Tue Jun 22 23:05 CET 2004 - Kevin Krammer <kevin.krammer@gmx.at>
o Move toolbar creation from XML GUI to code as a workaround
- because KHTML loads the plugins before it initializes its
+ because TDEHTML loads the plugins before it initializes its
d pointer and so there is no way to get to either the view or
the toolbar in the plugin's contructor.
diff --git a/konq-plugins/rellinks/Makefile.am b/konq-plugins/rellinks/Makefile.am
index f320d96..cb2540d 100644
--- a/konq-plugins/rellinks/Makefile.am
+++ b/konq-plugins/rellinks/Makefile.am
@@ -2,7 +2,7 @@ INCLUDES = $(all_includes)
METASOURCES = AUTO
kde_module_LTLIBRARIES = librellinksplugin.la
librellinksplugin_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
-librellinksplugin_la_LIBADD = $(LIB_KPARTS) $(LIB_KHTML)
+librellinksplugin_la_LIBADD = $(LIB_KPARTS) $(LIB_TDEHTML)
librellinksplugin_la_SOURCES = plugin_rellinks.cpp
plugins_DATA = plugin_rellinks.rc plugin_rellinks.desktop
pluginsdir = $(kde_datadir)/tdehtml/kpartplugins
diff --git a/konq-plugins/rellinks/plugin_rellinks.cpp b/konq-plugins/rellinks/plugin_rellinks.cpp
index 69a8e11..6bb3cbd 100644
--- a/konq-plugins/rellinks/plugin_rellinks.cpp
+++ b/konq-plugins/rellinks/plugin_rellinks.cpp
@@ -175,7 +175,7 @@ RelLinksPlugin::RelLinksPlugin(TQObject *parent, const char *name, const TQStrin
disableAll();
// When the rendering of the HTML is done, we update the site navigation bar
- m_part = dynamic_cast<KHTMLPart *>(parent);
+ m_part = dynamic_cast<TDEHTMLPart *>(parent);
if (!m_part)
return;
@@ -364,7 +364,7 @@ void RelLinksPlugin::updateToolbar() {
void RelLinksPlugin::guessRelations()
{
- m_part = dynamic_cast<KHTMLPart *>(parent());
+ m_part = dynamic_cast<TDEHTMLPart *>(parent());
if (!m_part || m_part->document().isNull() )
return;
@@ -421,8 +421,8 @@ void RelLinksPlugin::guessRelations()
/** Menu links */
void RelLinksPlugin::goToLink(const TQString & rel, int id) {
- // have the KHTML part open it
- KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
+ // have the TDEHTML part open it
+ TDEHTMLPart *part = dynamic_cast<TDEHTMLPart *>(parent());
if (!part)
return;
diff --git a/konq-plugins/rellinks/plugin_rellinks.h b/konq-plugins/rellinks/plugin_rellinks.h
index d791eb9..e8e5adb 100644
--- a/konq-plugins/rellinks/plugin_rellinks.h
+++ b/konq-plugins/rellinks/plugin_rellinks.h
@@ -44,8 +44,8 @@ typedef TQMap<TQString, KActionMenu*> KActionMenuMap;
// forward declarations
class KActionMenu;
-class KHTMLPart;
-class KHTMLView;
+class TDEHTMLPart;
+class TDEHTMLView;
class KToolBar;
class KURL;
class TQTimer;
@@ -70,13 +70,13 @@ private slots:
void delayedSetup();
/**
* KHTMLPart has created a new document, disable actions and
* start polling for links
*/
void newDocument();
/**
* KHTMLPart has finished loading, stop the poller and
* parse the document a last time.
*/
void loadingFinished();
@@ -149,8 +149,8 @@ private:
void goToLink(const TQString & rel, int id=0);
private:
- KHTMLPart* m_part;
- KHTMLView* m_view;
+ TDEHTMLPart* m_part;
+ TDEHTMLView* m_view;
bool m_viewVisible;
KActionMenu *m_document;
@@ -70,13 +70,13 @@ private slots:
void delayedSetup();
/**
- * KHTMLPart has created a new document, disable actions and
+ * TDEHTMLPart has created a new document, disable actions and
* start polling for links
*/
@@ -70,13 +70,13 @@ private slots:
void newDocument();
/**
- * KHTMLPart has finished loading, stop the poller and
+ * TDEHTMLPart has finished loading, stop the poller and
* parse the document a last time.
*/